==> haskell-threads-0.5.1.8-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-threads.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 threads
version:              0.5.1.8
visibility:           public
id:                   threads-0.5.1.8-TRcivFkEzjJPrV2TpyrZm
key:                  threads-0.5.1.8-TRcivFkEzjJPrV2TpyrZm
license:              BSD-3-Clause
copyright:            2010–2012 Bas van Dijk & Roel van Dijk
maintainer:
    Bas van Dijk <v.dijk.bas@gmail.com>
    Roel van Dijk <vandijk.roel@gmail.com>

author:
    Bas van Dijk <v.dijk.bas@gmail.com>
    Roel van Dijk <vandijk.roel@gmail.com>

stability:            experimental
homepage:             https://github.com/basvandijk/threads
synopsis:             Fork threads and wait for their result
description:
    This package provides functions to fork threads and
    wait for their result, whether it'\''s an exception or a
    normal value.

    Besides waiting for the termination of a single thread
    this packages also provides functions to wait for a
    group of threads to terminate.

    This package is similar to the
    @threadmanager@, @async@ and @spawn@ packages.
    The advantages of this package are:

    * Simpler API.

    * More efficient in both space and time.

    * No space-leak when forking a large number of threads.

    * Correct handling of asynchronous exceptions.

    * GHC specific functionality like @forkOn@ and @forkIOWithUnmask@.

category:             Concurrency
abi:                  8832c7178ca87d7ae02e68f95b4bcef5
exposed:              True
exposed-modules:
    Control.Concurrent.Thread Control.Concurrent.Thread.Group

hidden-modules:       Control.Concurrent.Raw
import-dirs:          /usr/lib/ghc-9.0.2/site-local/threads-0.5.1.8
library-dirs:         /usr/lib/ghc-9.0.2/site-local/threads-0.5.1.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-threads
hs-libraries:         HSthreads-0.5.1.8-TRcivFkEzjJPrV2TpyrZm
depends:              base-4.15.1.0 stm-2.5.0.0
haddock-interfaces:   /usr/share/doc/haskell-threads/html/threads.haddock
haddock-html:         /usr/share/doc/haskell-threads/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-threads-0.5.1.8-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-threads.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 threads
version:              0.5.1.8
visibility:           public
id:                   threads-0.5.1.8-8vR8Eo2Wm2yKM4VDeWTxg2
key:                  threads-0.5.1.8-8vR8Eo2Wm2yKM4VDeWTxg2
license:              BSD-3-Clause
copyright:            2010–2012 Bas van Dijk & Roel van Dijk
maintainer:
    Bas van Dijk <v.dijk.bas@gmail.com>
    Roel van Dijk <vandijk.roel@gmail.com>

author:
    Bas van Dijk <v.dijk.bas@gmail.com>
    Roel van Dijk <vandijk.roel@gmail.com>

stability:            experimental
homepage:             https://github.com/basvandijk/threads
synopsis:             Fork threads and wait for their result
description:
    This package provides functions to fork threads and
    wait for their result, whether it'\''s an exception or a
    normal value.

    Besides waiting for the termination of a single thread
    this packages also provides functions to wait for a
    group of threads to terminate.

    This package is similar to the
    @threadmanager@, @async@ and @spawn@ packages.
    The advantages of this package are:

    * Simpler API.

    * More efficient in both space and time.

    * No space-leak when forking a large number of threads.

    * Correct handling of asynchronous exceptions.

    * GHC specific functionality like @forkOn@ and @forkIOWithUnmask@.

category:             Concurrency
abi:                  a85a4fab8f983855a7efbe0e4970ca31
exposed:              True
exposed-modules:
    Control.Concurrent.Thread Control.Concurrent.Thread.Group

hidden-modules:       Control.Concurrent.Raw
import-dirs:          /usr/lib/ghc-9.0.2/site-local/threads-0.5.1.8
library-dirs:         /usr/lib/ghc-9.0.2/site-local/threads-0.5.1.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-threads
hs-libraries:         HSthreads-0.5.1.8-8vR8Eo2Wm2yKM4VDeWTxg2
depends:              base-4.15.1.0 stm-2.5.0.0
haddock-interfaces:   /usr/share/doc/haskell-threads/html/threads.haddock
haddock-html:         /usr/share/doc/haskell-threads/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
